@@ -197,10 +197,6 @@ def getJwtMannager(appInstance, jwtSecret, algorithm=None, headerName=None, head
             log.prettyJson(getJwtMannager, f'JWT apiKey', info, logLevel=log.SETTING)
         return jwtManager
 
-@Function
-def addJwt(jwtInstance):
-    ...
-
 @EncapsulateItWithGlobalException(message=JwtConstant.INVALID_API_KEY_MESSAGE, status=HttpStatus.UNAUTHORIZED)
 def createAccessToken(identity, contextList, deltaMinutes=0, headers=None, data=None, apiInstance=None):
     timeNow = UtcDateTimeUtil.now()
@@ -311,6 +307,14 @@ def addResource(apiInstance, appInstance):
         apiInstance.apiKeyManager.api = apiInstance
     except Exception as exception:
         log.warning(addResource, 'Not possible to add ApiKeyManager', exception=exception)
+    log.success(initialize, 'ApiKeyManager created')
+    return apiInstance.apiKeyManager
+
+def initialize(apiInstance, appInstance) :
+    log.success(initialize, 'ApiKeyManager is running')
+
+def shutdown(apiInstance, appInstance) :
+    log.success(shutdown, 'ApiKeyManager connection successfully closed')
 
 def retrieveApiInstance(apiInstance=None, arguments=None):
     apiInstance = FlaskUtil.retrieveApiInstance(apiInstance=apiInstance, arguments=arguments)
