@@ -10,8 +10,6 @@ from python_framework.api.src.service import SecurityManager
 from python_framework.api.src.service import ApiKeyManager
 from python_framework.api.src.service import SessionManager
 from python_framework.api.src.service.openapi import OpenApiManager
-from python_framework.api.src.service import SqlAlchemyProxy
-from python_framework.api.src.service import SchedulerManager
 from python_framework.api.src.annotation.GlobalExceptionAnnotation import EncapsulateItWithGlobalException
 from python_framework.api.src.constant import ConfigurationKeyConstant, JwtConstant, HealthCheckConstant
 import globals
@@ -156,8 +154,6 @@ def runApi(*args, api=None, **kwargs):
     log.success(runApi, f'Health check will be available at {healthCheckUrl}')
     log.success(runApi, f'Documentation will be available at {documentationUrl}')
     api.app.run(*args, **kwargs)
-    SchedulerManager.shutdown(api, api.app)
-    SqlAlchemyProxy.shutdown(api, api.app)
 
 @Function
 def getApiUrl(api):
